unit skiplabels;

{ :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
  :: QuickReport 3.0 for Delphi 3.0/4.0/5.0                  ::
  ::                                                         ::
  :: Sample report to show how to start labels at a specific ::
  :: spot on the page                                        ::
  ::                                                         ::
  :: Copyright (c) 1999 QuSoft AS                            ::
  :: All Rights Reserved                                     ::
  ::                                                         ::
  :: web: http://www.qusoft.no   fax: +47 22 41 74 91        ::
  ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: }

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  quickrpt, DB, DBTables, ExtCtrls, Qrctrls;

type
  TfrmSkipLabels = class(TForm)
    QuickRep1: TQuickRep;
    tbCust: TTable;
    DetailBand1: TQRBand;
    QRExpr1: TQRExpr;
    QRExpr2: TQRExpr;
    QRExpr3: TQRExpr;
    QRExpr4: TQRExpr;
    QuickRep2: TQuickRep;
    DetailBand2: TQRBand;
    QRExpr5: TQRExpr;
    QRExpr6: TQRExpr;
    QRExpr7: TQRExpr;
    QRExpr8: TQRExpr;
    SkipBand: TQRGroup;
    procedure QuickRep1BeforePrint(Sender: TCustomQuickRep;
      var PrintReport: Boolean);
    procedure QuickRep1NeedData(Sender: TObject; var MoreData: Boolean);
    procedure QRExpr2Print(sender: TObject; var Value: string);
  private
    { Private declarations }
    fSkipLabels: integer; { Used internally to skip labels}
  public
    { Public declarations }
    { Set this value to the number of labels to skip over }
    SkipLabels: integer;
  end;

var
  frmSkipLabels: TfrmSkipLabels;

implementation

{$R *.DFM}

procedure TfrmSkipLabels.QuickRep1BeforePrint(Sender: TCustomQuickRep;
  var PrintReport: Boolean);
begin
  { We need to offset the value by one }
  fSkipLabels := SkipLabels + 1;
end;

procedure TfrmSkipLabels.QuickRep1NeedData(Sender: TObject;
  var MoreData: Boolean);
begin
{
We are using the fSkipLabels variable as a counter for the number
of labels to skip.  When fSkipLabels goes below 0, we stop decrementing it.
}
  if fSkipLabels >= 0 then
    fSkipLabels := fSkipLabels - 1;

{
  We always set MoreData to true while we skipping labels.
}
  MoreData := fSkipLabels > 0;

{
  If we are not skipping labels, then we start navigating through the dataset
  manually and set MoreData while eof is false.  You must use QRExpr controls,
  QRDBText will not pick up the correct data while we use OnNeedData
}
  if not MoreData then
  begin
    with tbCust do
    begin
{
  If fSkipLabels is zero, we set the dataset to the start of the table,
  otherwise we find the next record.  If you need to start the from a record
  other than the first, you would replace the call to tbCust.First to a
  call that went to the starting record.
}
      if fSkipLabels = 0 then
        tbCust.First
      else
        Next;
      MoreData := not eof;
    end;
  end;
end;

procedure TfrmSkipLabels.QRExpr2Print(sender: TObject; var Value: string);
begin
  {
  All of the expressions use this OnPrint event to supress the output for
  labels that are being skipped
  }
  if fSkipLabels > 0 then Value := '';
end;

end.
